// java wrapper for vtkInformationIntegerVectorKey object
//

package vtk;
import vtk.*;

public class vtkInformationIntegerVectorKey extends vtkInformationKey
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native long MakeKey_2(String id0,String id1,int id2);
  public vtkInformationIntegerVectorKey MakeKey(String id0,String id1,int id2) {
    long temp = MakeKey_2(id0,id1,id2);

    if (temp == 0) return null;
    return (vtkInformationIntegerVectorKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void Append_3(vtkInformation id0,int id1);
  public void Append(vtkInformation id0,int id1)
    { Append_3(id0,id1); }

  private native void Set_4(vtkInformation id0);
  public void Set(vtkInformation id0)
    { Set_4(id0); }

  private native int Get_5(vtkInformation id0,int id1);
  public int Get(vtkInformation id0,int id1)
    { return Get_5(id0,id1); }

  private native int Length_6(vtkInformation id0);
  public int Length(vtkInformation id0)
    { return Length_6(id0); }

  private native void ShallowCopy_7(vtkInformation id0,vtkInformation id1);
  public void ShallowCopy(vtkInformation id0,vtkInformation id1)
    { ShallowCopy_7(id0,id1); }

  public vtkInformationIntegerVectorKey() { super(); }

  public vtkInformationIntegerVectorKey(long id) { super(id); }

}
